hugoBasicExample
==========

This is an example site for [Hugo](https://gohugo.io/).

It is intended to be a demo site for the various [Hugo themes][].

# Using

1. First, [install Hugo](https://gohugo.io/overview/installing/);
2. Then, clone this repository;
3. Clone the [Hugo themes][];
4. Run Hugo and select the theme of your choosing.

In other words:

<pre><code>git clone https://github.com/gohugoio/HugoBasicExample.git
cd HugoBasicExample
git clone --recursive https://github.com/gohugoio/hugoThemes.git themes
hugo server -t <em>themename</em>
</code></pre>

Enjoy!

[Hugo themes]: https://github.com/gohugoio/hugoThemes
